@@ -2,8 +2,6 @@ import argparse
 import json
 from pathlib import Path
 from azureml.core import Run, Dataset
-
-from aggregate_output import create_summary
 from azureml.core.datastore import Datastore
 from azureml.data.datapath import DataPath
 
@@ -35,11 +33,11 @@ workspace = run.experiment.workspace
 print("Loading Data...")
 data_output_dir_path = Path(img_dir)
 
-summary_filename = "summary_chunk" + str(chunk_index) + ".json"
+#summary_filename = "summary_chunk" + str(chunk_index) + ".json"
 chunk_name = "chunk" + str(chunk_index)
 json_chunk_name = "json" + chunk_name
 output_jsons = str(data_output_dir_path / json_chunk_name)
-create_summary(output_jsons, str(data_output_dir_path / summary_filename))
+#create_summary(output_jsons, str(data_output_dir_path / summary_filename))
 
 datastore = Datastore.get(workspace, save_datastore_name)
 dataset = Dataset.File.upload_directory(
